from odoo.addons.payment_stripe import utils
from odoo.addons.saas_worker.config import saas_config


get_publishable_key_base = utils.get_publishable_key
get_secret_key_base = utils.get_secret_key
get_webhook_secret_base = utils.get_webhook_secret


def get_publishable_key(provider_sudo):
    """ Patch of payment_stripe to retrieve the parent account's key from a config file. """
    base_publishable_key = get_publishable_key_base(provider_sudo)
    if not base_publishable_key and provider_sudo._stripe_has_connected_account():
        return get_config_value(provider_sudo, 'publishable_key')
    return base_publishable_key


def get_secret_key(provider_sudo):
    """ Patch of payment_stripe to retrieve the parent account's key from a config file. """
    base_secret_key = get_secret_key_base(provider_sudo)
    if not base_secret_key and provider_sudo._stripe_has_connected_account():
        return get_config_value(provider_sudo, 'secret_key')
    return base_secret_key


def get_webhook_secret(provider_sudo):
    """ Patch of payment_stripe to retrieve the parent account's key from a config file. """
    base_webhook_secret = get_webhook_secret_base(provider_sudo)
    if not base_webhook_secret and provider_sudo._stripe_has_connected_account():
        return get_config_value(provider_sudo, 'webhook_secret')
    return base_webhook_secret


def get_config_value(provider_sudo, config_key):
    """ Fetch and return the appropriate config value depending on the provider's platform account.

    :param recordset provider_sudo: The sudoed provider for which the config value must be fetched.
    :param str config_key: The config key mapped to the config value to fetch.
    :return: The config value.
    :rtype: str
    """
    platform_account = provider_sudo._stripe_select_platform_account()
    config_section = 'stripe' if platform_account == 'be' else 'stripe-us'
    return saas_config[config_section][config_key]


utils.get_publishable_key = get_publishable_key
utils.get_secret_key = get_secret_key
utils.get_webhook_secret = get_webhook_secret
